.txt file in GenePop format into an object of type genindadegenet::import2genind. However, that function requires text files with an extension of .gen, whereas such files usually have extension .txt. The sole purpose of this function is to work around the genepop.to.genind(name, quiet = TRUE)GenePop formatgenind